# StochMan - Stochastic Manifolds made easier

StochMan is a collection of elementary algorithms for computations on random manifolds learned from finite noisy data. Each algorithm assume that the considered manifold model implement a specific set of interfaces.


## Example: Geodesics on a sphere




